@@ -2,12 +2,9 @@
 #########################################################################################################
 # Imports
 import json as __json
-from ..error import SfcparseError
+from ..error import JsonExportFile
 from typing import Union
 
-# Exception for Module
-class JsonExportFile(SfcparseError): __module__ = SfcparseError.set_module_name()
-
 #########################################################################################################
 # Export json file
 def jsonexportfile(filename: str, data: Union[str, int, float, bool, list, dict, tuple, None]) -> None:
