@@ -2,12 +2,9 @@
 #########################################################################################################
 # Imports
 import json as __json
-from ..error import SfcparseError
+from ..error import JsonExportStr
 from typing import Union
 
-# Exception for Module
-class JsonExportStr(SfcparseError): __module__ = SfcparseError.set_module_name()
-
 #########################################################################################################
 # Export json str
 def jsonexportstr(data: Union[str, int, float, bool, list, dict, tuple, None], indent_level: int=4) -> str:
